% TEMPLATE FOR THESIS EXPOSE
% Created by: daniel.rotter@itsec.uni-hannover.de
% Updated: 2023-Nov-02
%
% Contact your advisor in case you have questions.

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{misc/usp_expose}[2023/11/02 LUH USP Expose]


% Definition of error messages that inform abut the wrong usage of this classes options
\newcommand{\languageerror}{
    \ClassError{usp_expose}{Cannot set expose language to both 'english' and 'german'}{Remove either 'english' or 'german' from the options list when loading this class}
    \stop  % Stop LaTeX compilation if more than one language is specified
}
\newcommand{\thesistypeerror}{
    \ClassError{usp_expose}{Cannot set expose type to both 'bachelor' and 'master'}{Remove either 'bachelor' or 'master' from the options list when loading this class}
    \stop  % Stop LaTeX compilation if more than one language is specified
}

% Define mutually exclusive options for language and thesis type
\DeclareOption{german}{
    \ifdefined\uspenglish \languageerror{} \fi
    \def\uspgerman{}
    \PassOptionsToClass{german}{scrartcl}
    \PassOptionsToPackage{main=ngerman}{babel}
}
\DeclareOption{english}{
    \ifdefined\uspgerman \languageerror{} \fi
    \def\uspenglish{}
    \PassOptionsToClass{\CurrentOption}{scrartcl}
    \PassOptionsToPackage{main=english}{babel}
}

\DeclareOption{bachelor}{
    \ifdefined\uspmaster \thesistypeerror{} \fi
    \def\uspbachelor{}
}
\DeclareOption{master}{
    \ifdefined\uspbachelor \thesistypeerror{} \fi
    \def\uspmaster{}
}

% Process all options and warn if any options are not used
\DeclareOption*{\OptionNotUsed}
\ProcessOptions*\relax
\LoadClass[a4paper,oneside,11pt]{scrartcl}

\RequirePackage{ifthen}

% Make sure that both the language and the thesis type have been set
\ifthenelse{\isundefined{\uspgerman} \AND \isundefined{\uspenglish}}{
    \ClassError{usp_expose}{Must set expose language to either 'english' or 'german'}{Add either 'english' or 'german' to the options list when loading this class}
    \stop  % Stop LaTeX compilation if no language is specified
}{}
\ifthenelse{\isundefined{\uspbachelor} \AND \isundefined{\uspmaster}}{
    \ClassError{usp_expose}{Must set expose type to either 'bachelor' and 'master'}{Add either 'bachelor' or 'master' to the options list when loading this class}
    \stop  % Stop LaTeX compilation if no language is specified
}{}

% Unicode input and output
\RequirePackage[utf8]{inputenc}
\RequirePackage[T1]{fontenc}

% The desired language should be automatically passed from the global options that were passed to this document class
\RequirePackage{babel}

% Define metadata (e.g., title, subject, university)
\input{misc/metadata}

\RequirePackage[pdftex]{graphicx,color}
\RequirePackage{graphicx}
\RequirePackage{epsfig}
\RequirePackage{caption}
\RequirePackage{enumerate}
\RequirePackage{times}
\RequirePackage{url}
\RequirePackage{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{blindtext}
\RequirePackage{tikz}
\RequirePackage{float}
\RequirePackage{etoolbox}

% Enable quotes by \enquote{}
\RequirePackage[babel,english=american]{csquotes}

% Hyperlinks and menu for your document
\RequirePackage[
    breaklinks,
    hyperindex,
    colorlinks,
    pdftex]
    {hyperref}

\RequirePackage[
    backend=biber,          % Default backend with full support for all features
    bibstyle=ieee,          % Use IEEE as bibliography style
    citestyle=numeric-comp, % Use compact numeric style for citations
    sorting=none,           % Process all entries in citation order
    maxbibnames=99,         % Show a maximum of 99 authors for each bibliography entry
    date=comp,              % Use long date format with compact ranges
    url=false,              % Hide URLs (except for @online entries)
    doi=true,               % Show DOIs with the corresponding hyperlink to doi.org
    isbn=false,             % Hide ISBN/ISSN/ISRN
    eprint=false]           % Hide eprint information
    {biblatex}

% Add bibliography
\addbibresource{bibliography.bib}

% Figure setup
\DeclareGraphicsExtensions{.pdf,.eps,.png,.jpg}
\graphicspath{{data/figures/},{data/plots/},{data/logos/}} % paths to graphics folders

% Always include title page and bibliography at the beginning/end of the document
\makeatletter
\AtEndPreamble{\hypersetup{
    pdfauthor       = {\@author},
    pdftitle        = {\@title},
    pdfsubject      = {\@thesistype},
    anchorcolor     = black,
    citecolor       = black,
    filecolor       = black,
    linkcolor       = black,
    menucolor       = black,
    urlcolor        = black,
    pdfpagelayout   = SinglePage}}
\makeatother
\AtBeginDocument{\input{misc/titlepage}}
\AtEndDocument{\printbibliography}
